/* Project name:
     HID_Read_Write (USB HID Read & Write Test)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Revision History:
     20111223:
       - initial release;
 * Description:
     This example establishes connection with the HID terminal that is active
     on the PC. Upon connection establishment, the HID Device Name will appear
     in the respective window. The character that user sends to ARM from the HID
     terminal will be re-sent back to user.
 * Test configuration:
     MCU:             STM32F107VC
                      http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
     Dev.Board:       EasyMx PRO v7 for STM32(R) ARM(R) - ac:USB
                      http://www.mikroe.com/easymx-pro/stm32/
     Oscillator:      HSE-PLL, 72.000MHz
     Ext. Modules:    -
     SW:              mikroC PRO for ARM
                      http://www.mikroe.com/mikroc/arm/
 * NOTES:  -  Turn on USB switches on SW12
*/

char readbuff[64];
char writebuff[64];
unsigned int ADC_VALUE;
unsigned int DS1820_VALUE;
unsigned int LM35_VALUE;

void USB0Interrupt() iv IVT_INT_OTG_FS{
  USB_Interrupt_Proc();
}



unsigned int ReadDS1820(){
  unsigned int temp;
  // Perform temperature reading
  Ow_Reset(&GPIOA_BASE, 3);                         // Onewire reset signal
  Ow_Write(&GPIOA_BASE, 3, 0xCC);                   // Issue command SKIP_ROM
  Ow_Write(&GPIOA_BASE, 3, 0x44);                   // Issue command CONVERT_T
  Delay_ms(750);

  Ow_Reset(&GPIOA_BASE, 3);
  Ow_Write(&GPIOA_BASE, 3, 0xCC);                   // Issue command SKIP_ROM
  Ow_Write(&GPIOA_BASE, 3, 0xBE);                   // Issue command READ_SCRATCHPAD

  temp =  Ow_Read(&GPIOA_BASE, 3);
  temp = (Ow_Read(&GPIOA_BASE, 3) << 8) + temp;
  return temp;
}


void main(void){

  ADC_Set_Input_Channel(_ADC_CHANNEL_4 | _ADC_CHANNEL_10);
  
  HID_Enable(&readbuff,&writebuff);
  
  while(1){
    while(!HID_Read())
      ;
      //read temp. on DS1820
      DS1820_VALUE = ReadDS1820();
      //put value in output buffer
      writebuff[0]=(char)((DS1820_VALUE >> 8) & 0xFF);
      writebuff[1]=(char)(DS1820_VALUE & 0xFF);
      
      //read temp. on LM35
      LM35_VALUE = ADC1_Read(10);
      delay_ms(10);
      //put value in output buffer
      writebuff[2]=(char)((LM35_VALUE >> 8) & 0xFF);
      writebuff[3]=(char)(LM35_VALUE & 0xFF);
      
      //Read ADC value on PA4
      ADC_VALUE = ADC1_Read(4);
      delay_ms(10);
      //put value in output buffer
      writebuff[4]=(char)((ADC_VALUE >> 8) & 0xFF);
      writebuff[5]=(char)(ADC_VALUE & 0xFF);
      
    while(!HID_Write(&writebuff,64))
      ;
  }
}